import os
import unittest

from integration.integration_test_utils import IntegrationTestUtils
from integration.test_deposition import TestDeposition


class DepoAsserts(TestDeposition):


    def test_standard_run_input_status_success(self):
        status_file_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR, "STATUS_SUCCESS")
        success_file_exists: bool = os.path.isfile(status_file_path)
        self.assertTrue(success_file_exists)


    def test_standard_run_input_all_regions_ran(self):
        """
        working on the assumption that if there are images for each region, it must have run through
        (at least past the region iteration)
        """

        east_africa_image_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                              "plotting", "eastafrica", "images", "Weekly",
                                              "deposition_eastafrica_leaf_rust_total_202210010000_202210080000_map.png")
        ethiopia_image_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                           "plotting", "ethiopia", "images", "Weekly",
                                           "deposition_ethiopia_leaf_rust_total_202210010000_202210080000_map.png")

        ea_file_exists: bool = os.path.isfile(east_africa_image_path)
        eth_file_exists: bool = os.path.isfile(ethiopia_image_path)
        self.assertTrue(ea_file_exists)
        self.assertTrue(eth_file_exists)


    def test_standard_run_all_input_csvs_produced(self):
        east_africa_csv_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                            "plotting", "eastafrica", "input_csvs", "*.csv")
        ethiopia_csv_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                         "plotting", "ethiopia", "input_csvs", "*.csv")

        ea_csv_count: int = IntegrationTestUtils.count_files_in_wildcard(east_africa_csv_path)
        eth_csv_count: int = IntegrationTestUtils.count_files_in_wildcard(ethiopia_csv_path)
        self.assertEqual(9, ea_csv_count)
        self.assertEqual(27, eth_csv_count)


    def test_standard_run_all_images_produced(self):
        east_africa_image_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                              "plotting", "eastafrica", "images", "Weekly", "*.png")
        ethiopia_image_path = os.path.join(TestDeposition.TEST_OUT_PATH, TestDeposition.TEST_JOB_DIR,
                                           "plotting", "ethiopia", "images", "Weekly", "*.png")

        ea_csv_count: int = IntegrationTestUtils.count_files_in_wildcard(east_africa_image_path)
        eth_csv_count: int = IntegrationTestUtils.count_files_in_wildcard(ethiopia_image_path)
        self.assertEqual(3, ea_csv_count)
        self.assertEqual(6, eth_csv_count)


if __name__ == '__main__':
    unittest.main()
